pinax-points
============

pinax-points, formerly agon, provides the ability to track points on arbitrary
objects in your system.  The common case being ``User`` instances. It can
additionally keep track of positions for these objects to produce leaderboards.

This code has mostly been pulled out of `typewar`_ and made slightly more
generic to work well.

.. _typewar: http://typewar.com/


.. image:: https://img.shields.io/travis/pinax/pinax-points.svg
    :target: https://travis-ci.org/pinax/pinax-points

.. image:: https://img.shields.io/coveralls/pinax/pinax-points.svg
    :target: https://coveralls.io/r/pinax/pinax-points

.. image:: https://img.shields.io/pypi/dm/pinax-points.svg
    :target:  https://pypi.python.org/pypi/pinax-points/

.. image:: https://img.shields.io/pypi/v/pinax-points.svg
    :target:  https://pypi.python.org/pypi/pinax-points/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/pinax-points/


Welcome to the documentation for pinax-points!


Running the Tests
------------------------------------

::

    $ pip install detox
    $ detox
